@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0105';
+our $VERSION = '0.0106';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -58,17 +58,19 @@ sub generate {
 
     my $cn = Music::Chord::Note->new;
 
-    my @notes = $cn->chord_with_octave($chord, $self->octave);
+    my @notes = map { Music::Note->new($_, 'ISO')->format('midinum') }
+        $cn->chord_with_octave($chord, $self->octave);
 
     my @pitches = get_scale_MIDI($chord_note, $self->octave, $scale);
 
     # Add unique chord notes to the pitches
-    my @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @pitches;
     for my $n (@notes) {
-        if (not any { $_ eq $n } @named) {
-            my $x = Music::Note->new($n, 'ISO')->format('midinum');
-            push @pitches, $x;
-            print "\tADD: $n\n" if $self->verbose;
+        if (not any { $_ == $n } @pitches) {
+            push @pitches, $n;
+            if ($self->verbose) {
+                my $x = Music::Note->new($n, 'midinum')->format('ISO');
+                print "\tADD: $x\n";
+            }
         }
     }
     @pitches = sort { $a <=> $b } @pitches; # Pitches are midi numbers
@@ -78,19 +80,27 @@ sub generate {
     print "\tSCALE: ",ddc(\@tones) if $self->verbose;
     my @fixed;
     for my $p (@pitches) {
-        my $x = Music::Note->new($p, 'midinum')->format('isobase');
+        my $n = Music::Note->new($p, 'midinum');
+        my $x = $n->format('isobase');
+        if ($x =~ /#/) {
+            $n->en_eq('flat');
+        }
+        elsif ($x =~ /b/) {
+            $n->en_eq('sharp');
+        }
+        my $y = $n->format('isobase');
         if (
-            ($flavor =~ /5/ && $x eq $tones[4])
+            ($flavor =~ /[#b]5/ && ($x eq $tones[4] || $y eq $tones[6]))
             ||
-            ($flavor =~ /7/ && $flavor !~ /M7/ && $x eq $tones[6])
+            ($flavor =~ /7/ && $flavor !~ /[Mm]7/ && ($x eq $tones[6] || $y eq $tones[6]))
             ||
-            ($flavor =~ /[#b]9/ && $x eq $tones[1])
+            ($flavor =~ /[#b]9/ && ($x eq $tones[1] || $y eq $tones[6]))
             ||
-            ($flavor =~ /dim/ && $x eq $tones[2])
+            ($flavor =~ /dim/ && ($x eq $tones[2] || $y eq $tones[6]))
             ||
-            ($flavor =~ /dim/ && $x eq $tones[6])
+            ($flavor =~ /dim/ && ($x eq $tones[6] || $y eq $tones[6]))
             ||
-            ($flavor =~ /aug/ && $x eq $tones[6])
+            ($flavor =~ /aug/ && ($x eq $tones[6] || $y eq $tones[6]))
         ) {
             print "\tDROP: $x\n" if $self->verbose;
             next;
@@ -98,9 +108,12 @@ sub generate {
         push @fixed, $p;
     }
 
-    # Debugging:
-    @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @fixed;
-    print "\tNOTES: ",ddc(\@named) if $self->verbose;
+    # DEBUGGING:
+    my @named;
+    if ($self->verbose) {
+        @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @fixed;
+        print "\tNOTES: ",ddc(\@named);
+    }
 
     my $voice = Music::VoiceGen->new(
         pitches   => \@fixed,
@@ -114,8 +127,10 @@ sub generate {
     my @chosen = map { $voice->rand } 1 .. $num;;
 
     # Show them what they've won, Bob!
-    @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @chosen;
-    print "\tCHOSEN: ",ddc(\@named) if $self->verbose;
+    if ($self->verbose) {
+        @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @chosen;
+        print "\tCHOSEN: ",ddc(\@named);
+    }
 
     return \@chosen;
 }
@@ -134,7 +149,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0105
+version 0.0106
 
 =head1 SYNOPSIS
 
